@@ -15,6 +15,7 @@ import logging
 import numpy as np
 import pandas
 import scipy.constants
+import json
 from math import pi, sqrt, floor, ceil
 from scipy.spatial.transform import Rotation
 
@@ -564,6 +565,9 @@ class AtomData(object):
                 for chain in model:
                     for residue in chain:
                         for atom in residue:
+                            if atom.element.atomic_number <= 0:
+                                print("BAD ELEMENT")
+                                continue
                             assert atom.element.atomic_number > 0
                             yield (
                                 atom.element.atomic_number,
@@ -1235,7 +1239,6 @@ class Sample(object):
 
         # Check the old bounding box
         if self.number_of_atoms > 0:
-
             # Get the bounding box
             (bx0, by0, bz0), (bx1, by1, bz1) = self.bounding_box
 
@@ -1325,7 +1328,6 @@ class Sample(object):
         for position, rotation, orientation in zip(
             positions, Rotation.from_rotvec(orientations), orientations
         ):
-
             # Make a copy and apply the rotation and translation
             coords = (rotation.apply(reference_coords) + position).astype("float32")
             temp = atoms.data.copy()
@@ -1615,6 +1617,34 @@ class Sample(object):
             str: Some sample info
 
         """
+
+        class NumpyEncoder(json.JSONEncoder):
+            """Special json encoder for numpy types"""
+
+            def default(self, obj):
+                if isinstance(
+                    obj,
+                    (
+                        np.int_,
+                        np.intc,
+                        np.intp,
+                        np.int8,
+                        np.int16,
+                        np.int32,
+                        np.int64,
+                        np.uint8,
+                        np.uint16,
+                        np.uint32,
+                        np.uint64,
+                    ),
+                ):
+                    return int(obj)
+                elif isinstance(obj, (np.float_, np.float16, np.float32, np.float64)):
+                    return float(obj)
+                elif isinstance(obj, (np.ndarray,)):
+                    return obj.tolist()
+                return json.JSONEncoder.default(self, obj)
+
         lines = [
             "Sample information:",
             "    # Molecules:   %d" % self.number_of_molecules,
@@ -1638,7 +1668,8 @@ class Sample(object):
             "    Centre x:      %.2f" % self.centre[0],
             "    Centre y:      %.2f" % self.centre[1],
             "    Centre z:      %.2f" % self.centre[2],
-            "    Shape:         %s" % str(self.shape),
+            "    Shape:         %s"
+            % json.dumps(self.shape, cls=NumpyEncoder, indent=2),
         ]
         for name, molecule in self.iter_molecules():
             molecule_lines = [
@@ -1902,8 +1933,7 @@ class AtomDeleter(object):
         # from matplotlib import pylab
         # pylab.imshow(self.grid[:,:,grid_shape[2]//2])
         # pylab.show()
-
-        self.grid = scipy.ndimage.distance_transform_edt(self.grid) < min_distance
+        # self.grid = scipy.ndimage.distance_transform_edt(~self.grid) < min_distance
         return
         # self.grid = scipy.ndimage.morphology.binary_closing(self.grid, iterations=2)
         # self.grid = scipy.ndimage.morphology.binary_fill_holes(self.grid)
