@@ -69,6 +69,7 @@ class ImageSimulator(object):
         # Get the rotation angle
         angle = self.scan.angles[index]
         exposure_time = self.scan.exposure_time[index]
+        electrons_per_angstrom = self.scan.electrons_per_angstrom[index]
         if exposure_time <= 0:
             exposure_time = 1.0
 
@@ -80,8 +81,7 @@ class ImageSimulator(object):
 
         # Compute the number of counts per pixel
         electrons_per_pixel = (
-            self.microscope.beam.electrons_per_angstrom
-            * self.microscope.detector.pixel_size**2
+            electrons_per_angstrom * self.microscope.detector.pixel_size**2
         )
 
         # Compute the electrons per pixel second
@@ -117,7 +117,7 @@ class ImageSimulator(object):
 
         # Get the image metadata
         metadata = np.asarray(self.optics.header[index])
-        metadata["dose"] = self.microscope.beam.electrons_per_angstrom
+        metadata["dose"] = electrons_per_angstrom
         metadata["dqe"] = self.microscope.detector.dqe
         metadata["gain"] = 1
         metadata["offset"] = 0
@@ -188,7 +188,7 @@ def image(config_file, optics_file: str, image_file: str):
     _image_Config(config, optics_file, image_file)
 
 
-@image.register
+@image.register(parakeet.config.Config)
 def _image_Config(config: parakeet.config.Config, optics_file: str, image_file: str):
     """
     Simulate the image with noise
@@ -210,6 +210,13 @@ def _image_Config(config: parakeet.config.Config, optics_file: str, image_file:
     # Create the scan
     scan = optics.header.scan
 
+    # Override the dose
+    scan_new = parakeet.scan.new(
+        electrons_per_angstrom=microscope.beam.electrons_per_angstrom,
+        **config.scan.dict(),
+    )
+    scan.data["electrons_per_angstrom"] = scan_new.electrons_per_angstrom
+
     # Create the simulation
     simulation = simulation_factory(
         microscope=microscope,
