@@ -27,10 +27,6 @@ from math import sqrt
 from parakeet.simulate.simulation import Simulation
 
 
-Device = parakeet.config.Device
-ClusterMethod = parakeet.config.ClusterMethod
-
-
 __all__ = ["optics"]
 
 
@@ -87,7 +83,6 @@ class OpticsImageSimulator(object):
         def compute_image(
             psi, microscope, simulation, x_fov, y_fov, offset, device, defocus=None
         ):
-
             # Create the multem system configuration
             system_conf = parakeet.simulate.simulation.create_system_configuration(
                 device
@@ -110,6 +105,14 @@ class OpticsImageSimulator(object):
             # Compute and apply the CTF
             ctf = np.array(multem.compute_ctf(system_conf, input_multislice)).T
 
+            # Add the effect of the phase plate
+            if microscope.phase_plate.use:
+                ctf = ctf * parakeet.simulate.phase_plate.compute_phase_shift(
+                    ctf.shape,
+                    microscope.detector.pixel_size,
+                    microscope.phase_plate.phase_shift,
+                    microscope.phase_plate.radius,
+                )
             # Compute the B factor for radiation damage
             # if simulation["radiation_damage_model"]:
             #    sigma_B = sqrt(
@@ -163,7 +166,6 @@ class OpticsImageSimulator(object):
         shape = self.sample["shape"]
         energy_shift = 0
         if self.simulation["inelastic_model"] is None:
-
             # If no inelastic model just calculate image as normal
             image = compute_image(
                 psi,
@@ -178,7 +180,6 @@ class OpticsImageSimulator(object):
             electron_fraction = 1.0
 
         elif self.simulation["inelastic_model"] == "zero_loss":
-
             # Compute the image
             image = compute_image(
                 psi,
@@ -198,7 +199,6 @@ class OpticsImageSimulator(object):
             image *= electron_fraction
 
         elif self.simulation["inelastic_model"] == "mp_loss":
-
             # Set the filter width
             filter_width = self.simulation["mp_loss_width"]  # eV
 
@@ -286,7 +286,6 @@ class OpticsImageSimulator(object):
             image = elastic_fraction * image1 + inelastic_fraction * image2
 
         elif self.simulation["inelastic_model"] == "unfiltered":
-
             # Compute the energy and spread of the plasmon peak
             peak, sigma = parakeet.inelastic.most_probable_loss(
                 microscope.beam.energy, shape, angle
@@ -335,7 +334,6 @@ class OpticsImageSimulator(object):
             image = zero_loss_fraction * image1 + mp_loss_fraction * image2
 
         elif self.simulation["inelastic_model"] == "cc_corrected":
-
             # Set the Cs and CC to zero
             microscope.lens.c_30 = 0
             microscope.lens.c_c = 0
@@ -459,7 +457,7 @@ def simulation_factory(
     microscope: Microscope,
     exit_wave: object,
     scan: Scan,
-    device: Device = Device.gpu,
+    device: parakeet.config.Device = parakeet.config.Device.gpu,
     simulation: dict = None,
     sample: dict = None,
     cluster: dict = None,
@@ -502,8 +500,8 @@ def optics(
     config_file,
     exit_wave_file: str,
     optics_file: str,
-    device: Device = Device.gpu,
-    cluster_method: ClusterMethod = None,
+    device: parakeet.config.Device = parakeet.config.Device.gpu,
+    cluster_method: parakeet.config.ClusterMethod = None,
     cluster_max_workers: int = 1,
 ):
     """
@@ -537,7 +535,7 @@ def optics(
     _optics_Config(config, exit_wave_file, optics_file)
 
 
-@optics.register
+@optics.register(parakeet.config.Config)
 def _optics_Config(
     config: parakeet.config.Config, exit_wave_file: str, optics_file: str
 ):
