@@ -121,7 +121,6 @@ def compute_potential():
     """
 
     def compute(atom_data, pixel_size, thickness):
-
         # Get the dimensions
         x_min = atom_data.data["x"].min()
         x_max = atom_data.data["x"].max()
@@ -231,7 +230,6 @@ def compute_observed_mean(size, pixel_size):
     # For N random placements compute the mean intensity
     means = []
     for j in range(10):
-
         # Compute the position
         x0 = np.random.uniform(0, 1) + nx // 2
         y0 = np.random.uniform(0, 1) + ny // 2
@@ -324,9 +322,10 @@ def compute_mean_correction(ax=None):
             outfile.write("%.2f, %.7f\n" % (x, y))
 
     # Plot the mean correction
-    ax.plot(area, mean)
-    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(b)")
-    ax.set_title("Mean correction factor")
+    ax.plot(area, mean, label="Mean correction")
+    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(c)", fontsize=9)
+    ax.set_title("Mean correction factor", fontsize=9)
+    ax.set_xlim(0, 4)
 
 
 def compute_mean_correction2(ax=None):
@@ -341,7 +340,6 @@ def compute_mean_correction2(ax=None):
     # Loop through the pixel sizes
     thickness = 20
     for pixel_size in np.arange(0.1, 2.1, 0.1):
-
         # Read the projected potential
         handle = np.load("potential_%.1f_%d.npz" % (pixel_size, thickness))
         potential = handle["potential"]
@@ -384,8 +382,9 @@ def compute_mean_correction2(ax=None):
 
     # Plot
     ax.plot(X, Y)
-    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(c)")
-    ax.set_title("Mean correction factor")
+    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(d)", fontsize=9)
+    ax.set_title("Mean correction factor", fontsize=9)
+    ax.set_xlim(0, 4)
 
 
 def compute_variance_correction(ax=None):
@@ -400,7 +399,6 @@ def compute_variance_correction(ax=None):
     # Loop through the pixel sizes
     thickness = 20
     for pixel_size in np.arange(0.1, 2.1, 0.1):
-
         # Read the projected potential
         handle = np.load("potential_%.1f_%d.npz" % (pixel_size, thickness))
         potential = handle["potential"]
@@ -442,9 +440,10 @@ def compute_variance_correction(ax=None):
             outfile.write("%.2f, %.7f\n" % (x, y))
 
     # Plot
-    ax.plot(X, Y)
-    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(c)")
-    ax.set_title("Variance correction factor")
+    ax.plot(X, Y, label="Variance correction")
+    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(c)", fontsize=9)
+    ax.set_title("Mean and variance correction factors", fontsize=9)
+    ax.set_xlim(0, 4)
 
 
 def compute_power(ax=None):
@@ -456,7 +455,6 @@ def compute_power(ax=None):
     # Compute the fit to the power spectrum
     pixel_size = 0.1
     for thickness in [20]:  # , 19, 18, 15, 10, 5]:
-
         # Read the projected potential
         handle = np.load("potential_%.1f_%d.npz" % (pixel_size, thickness))
         potential = handle["potential"]
@@ -554,16 +552,82 @@ def compute_power(ax=None):
         d = np.arange(rp.size) / (pixel_size * power.shape[0])
 
         # Plot the power spectrum and best fit
-        ax.plot(d[1:], rp[1:] / C, label="%d" % thickness)
+        ax.plot(d[1:], rp[1:] / C)  # , label="%d" % thickness)
         ax.plot(d[1:], rm[1:] / C, color="black", alpha=0.5, label="Model")
 
     # Set some plot properties
-    ax.set_xlabel("Spatial frequency ($Å$)\n(a)")
-    ax.set_title("Power spectrum")
+    ax.set_xlabel("Spatial frequency ($Å^{-1}$)\n(a)", fontsize=9)
+    ax.set_title("Power spectrum", fontsize=9)
     ax.set_xlim(0, 1)
+    ax.legend(fontsize=9)
     ax.set_yticklabels("")
 
 
+def compute_correlation(ax=None):
+    """
+    Compute the correlation length
+
+    """
+
+    pixel_size = 0.1
+    for thickness in [5]:  # , 19, 18, 15, 10, 5]:
+        # Read the projected potential
+        handle = np.load("potential_%.1f_%d.npz" % (pixel_size, thickness))
+        potential = handle["potential"]
+        num_atoms = handle["num_atoms"]
+
+        # Select the pixels with potential in
+        xsize, ysize = potential.shape
+        x0 = xsize // 8
+        x1 = 7 * xsize // 8
+        y0 = ysize // 8
+        y1 = 7 * ysize // 8
+        potential = potential[x0:x1, y0:y1]
+
+        data = potential
+        data = data - np.mean(data)
+        f = np.fft.fft2(data)
+        power = np.abs(f) ** 2
+        corr = np.abs(np.fft.ifft2(power))
+        corr = np.fft.fftshift(corr)
+        corr = corr / (corr.size * np.var(data))
+
+        rc = radial_average(corr)[0 : data.shape[0] // 2]
+        rd = np.arange(rc.size) * pixel_size
+        rc = rc / np.max(rc)
+
+        corr_length = 0
+        val = rc[0] / np.exp(1)
+        for d, c in zip(rd, rc):
+            if c < val:
+                corr_length = d
+                break
+
+    print("Correlation Length: %f" % corr_length)
+
+    # Plot the correlation
+    if ax is None:
+        width = 0.0393701 * 190
+        height = width * 0.74
+        fig, ax = pylab.subplots(figsize=(width, height), constrained_layout=True)
+    ax.plot(rd, rc)
+    ax.axvline(
+        corr_length,
+        color="black",
+        linestyle="--",
+        label="$𝜉 = %.1f Å$" % corr_length,
+    )
+
+    # Set some plot properties
+    ax.set_xlabel("Distance ($Å$)\n(b)", fontsize=9)
+    ax.set_title("Autocorrelation", fontsize=9)
+    ax.set_xlim(0, 2.5)
+    ax.legend(fontsize=9)
+    if ax is None:
+        fig.savefig("correlation_%.1fA.png" % pixel_size, dpi=300, bbox_inches="tight")
+        pylab.close("all")
+
+
 def calibrate():
     """
     Calibrate ice model
@@ -580,9 +644,13 @@ def calibrate():
     height = width / 3.0
     fig, ax = pylab.subplots(ncols=3, figsize=(width, height), constrained_layout=True)
     compute_power(ax[0])
-    compute_mean_correction(ax[1])
+    compute_correlation(ax[1])
+    compute_mean_correction(ax[2])
     # compute_mean_correction2(ax[1])
     compute_variance_correction(ax[2])
+    ax[2].legend(fontsize=9)
+    for axx in ax:
+        axx.tick_params(axis="both", labelsize=9)
     fig.savefig("model.png", dpi=300, bbox_inches="tight")
 
 
@@ -684,7 +752,6 @@ def compute_exit_wave(atom_data, pixel_size):
 
 
 def load_exit_wave(atom_data, ps):
-
     physical_filename = "exit_wave_physical_%.1f.mrc" % ps
     random_filename = "exit_wave_random_%.1f.mrc" % ps
     metadata_filename = "metadata_%.1f.dat" % ps
@@ -715,7 +782,6 @@ def load_exit_wave(atom_data, ps):
 
 
 def plot_mean_and_var(physical_data, random_data, xmin, xmax, ps):
-
     x0 = np.floor(xmin / ps).astype("int32")
     x1 = np.floor(xmax / ps).astype("int32")
     xr = x1 - x0
@@ -816,7 +882,6 @@ def plot_mean_and_var(physical_data, random_data, xmin, xmax, ps):
 
 
 def plot_power(physical_data, random_data, xmin, xmax, ps):
-
     x0 = np.floor(xmin / ps).astype("int32")
     x1 = np.floor(xmax / ps).astype("int32")
     xr = x1 - x0
@@ -866,7 +931,6 @@ def plot_power(physical_data, random_data, xmin, xmax, ps):
 
 
 def plot_edge(physical_data, random_data, xmin, xmax, ps):
-
     x0 = np.floor(xmin / ps).astype("int32")
     x1 = np.floor(xmax / ps).astype("int32")
     xd = x1 - x0
@@ -1051,7 +1115,6 @@ def plot_all_mean_and_power(pixel_size, stats_list, power_list):
 
 
 def plot_all_edge(pixel_size, edge_list):
-
     width = 0.0393701 * 190
     height = 0.5 * width
     fig, ax = pylab.subplots(
@@ -1062,7 +1125,6 @@ def plot_all_edge(pixel_size, edge_list):
     edge_list = [edge_list[i] for i in [0, 3, 6, 9]]
 
     for i, (ps, edge) in enumerate(zip(pixel_size, edge_list)):
-
         vmin = min(np.min(edge[0]), np.min(edge[0]))
         vmax = max(np.max(edge[1]), np.max(edge[1]))
 
@@ -1103,7 +1165,6 @@ def validate():
     edge_list = []
 
     for ps in pixel_size:
-
         # Get the simulated exit wave
         physical_data, random_data, xmin, xmax = load_exit_wave(atom_data, ps)
 
@@ -1123,7 +1184,6 @@ def validate():
 
 
 if __name__ == "__main__":
-
     # Create the argument parser
     parser = argparse.ArgumentParser(description="Do the ice model configuration")
 
